MPESA
This a package that is used to help developers integrate their python projects with mpesa

Once you have installed the package, you will have to produce a token using the consumer key and consumer secrete that is assigned to your project and you can use this access token in the other functions.

You can fill in the required details acording to the documentation found on the safaricom site documentation: https://developer.safaricom.co.ke/docs